@@ -138,6 +138,8 @@ class CreateJobRequest(AbstractModel):
         :type Remark: str
         :param FolderId: 作业名所属文件夹ID，根目录为"root"
         :type FolderId: str
+        :param FlinkVersion: 作业运行的Flink版本
+        :type FlinkVersion: str
         """
         self.Name = None
         self.JobType = None
@@ -146,6 +148,7 @@ class CreateJobRequest(AbstractModel):
         self.CuMem = None
         self.Remark = None
         self.FolderId = None
+        self.FlinkVersion = None
 
 
     def _deserialize(self, params):
@@ -156,6 +159,7 @@ class CreateJobRequest(AbstractModel):
         self.CuMem = params.get("CuMem")
         self.Remark = params.get("Remark")
         self.FolderId = params.get("FolderId")
+        self.FlinkVersion = params.get("FlinkVersion")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -254,30 +258,34 @@ class CreateResourceRequest(AbstractModel):
         r"""
         :param ResourceLoc: 资源位置
         :type ResourceLoc: :class:`tencentcloud.oceanus.v20190422.models.ResourceLoc`
-        :param Name: 资源名称
-        :type Name: str
         :param ResourceType: 资源类型。目前只支持 JAR，取值为 1
         :type ResourceType: int
         :param Remark: 资源描述
         :type Remark: str
+        :param Name: 资源名称
+        :type Name: str
         :param ResourceConfigRemark: 资源版本描述
         :type ResourceConfigRemark: str
+        :param FolderId: 目录ID
+        :type FolderId: str
         """
         self.ResourceLoc = None
-        self.Name = None
         self.ResourceType = None
         self.Remark = None
+        self.Name = None
         self.ResourceConfigRemark = None
+        self.FolderId = None
 
 
     def _deserialize(self, params):
         if params.get("ResourceLoc") is not None:
             self.ResourceLoc = ResourceLoc()
             self.ResourceLoc._deserialize(params.get("ResourceLoc"))
-        self.Name = params.get("Name")
         self.ResourceType = params.get("ResourceType")
         self.Remark = params.get("Remark")
+        self.Name = params.get("Name")
         self.ResourceConfigRemark = params.get("ResourceConfigRemark")
+        self.FolderId = params.get("FolderId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -686,11 +694,14 @@ class DescribeResourceRelatedJobsRequest(AbstractModel):
         :type Offset: int
         :param Limit: 分页大小，默认为20，最大值为100
         :type Limit: int
+        :param ResourceConfigVersion: 资源版本号
+        :type ResourceConfigVersion: int
         """
         self.ResourceId = None
         self.DESCByJobConfigCreateTime = None
         self.Offset = None
         self.Limit = None
+        self.ResourceConfigVersion = None
 
 
     def _deserialize(self, params):
@@ -698,6 +709,7 @@ class DescribeResourceRelatedJobsRequest(AbstractModel):
         self.DESCByJobConfigCreateTime = params.get("DESCByJobConfigCreateTime")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        self.ResourceConfigVersion = params.get("ResourceConfigVersion")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -826,12 +838,15 @@ class DescribeSystemResourcesRequest(AbstractModel):
         :type Filters: list of Filter
         :param ClusterId: 集群ID
         :type ClusterId: str
+        :param FlinkVersion: 查询对应Flink版本的内置connector
+        :type FlinkVersion: str
         """
         self.ResourceIds = None
         self.Offset = None
         self.Limit = None
         self.Filters = None
         self.ClusterId = None
+        self.FlinkVersion = None
 
 
     def _deserialize(self, params):
@@ -845,6 +860,7 @@ class DescribeSystemResourcesRequest(AbstractModel):
                 obj._deserialize(item)
                 self.Filters.append(obj)
         self.ClusterId = params.get("ClusterId")
+        self.FlinkVersion = params.get("FlinkVersion")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1110,6 +1126,9 @@ class JobV1(AbstractModel):
         :param RunningCu: 细粒度下的运行的CU数量
 注意：此字段可能返回 null，表示取不到有效值。
         :type RunningCu: float
+        :param FlinkVersion: 作业运行的 Flink 版本
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FlinkVersion: str
         """
         self.JobId = None
         self.Region = None
@@ -1139,6 +1158,7 @@ class JobV1(AbstractModel):
         self.SchedulerType = None
         self.ClusterStatus = None
         self.RunningCu = None
+        self.FlinkVersion = None
 
 
     def _deserialize(self, params):
@@ -1170,6 +1190,7 @@ class JobV1(AbstractModel):
         self.SchedulerType = params.get("SchedulerType")
         self.ClusterStatus = params.get("ClusterStatus")
         self.RunningCu = params.get("RunningCu")
+        self.FlinkVersion = params.get("FlinkVersion")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
