@@ -26,6 +26,34 @@ class SesClient(AbstractClient):
     _service = 'ses'
 
 
+    def BatchSendEmail(self, request):
+        """您可以通过此API批量发送TEXT或者HTML邮件，适用于营销类、通知类邮件。默认仅支持使用模板发送邮件，如需发送自定义内容，请单独联系商务开通此功能。批量发送之前，需先创建收件人列表，和收件人地址，并通过收件人列表id来进行发送。批量发送任务支持定时发送和周期重复发送，定时发送需传TimedParam，周期重复发送需传CycleParam
+
+        :param request: Request instance for BatchSendEmail.
+        :type request: :class:`tencentcloud.ses.v20201002.models.BatchSendEmailRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.BatchSendEmailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("BatchSendEmail", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.BatchSendEmailResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateEmailAddress(self, request):
         """在验证了发信域名之后，您需要一个发信地址来发送邮件。例如发信域名是mail.qcloud.com，那么发信地址可以为 service@mail.qcloud.com。如果您想要收件人在收件箱列表中显示您的别名，例如"腾讯云邮件通知"。那么发信地址为： 别名 空格 尖括号 邮箱地址。请注意中间需要有空格
 
@@ -448,7 +476,7 @@ class SesClient(AbstractClient):
 
 
     def SendEmail(self, request):
-        """您可以通过此API发送TEXT或者HTML邮件，默认仅支持使用模板发送邮件，如需发送自定义内容，请单独联系商务开通此功能。
+        """您可以通过此API发送TEXT或者HTML邮件，适用于触发类邮件（验证码、交易类）。默认仅支持使用模板发送邮件，如需发送自定义内容，请单独联系商务开通此功能。
 
         :param request: Request instance for SendEmail.
         :type request: :class:`tencentcloud.ses.v20201002.models.SendEmailRequest`
